@@ -36,6 +36,7 @@ const PROTO_FILES: &[&str] = &[
     "vendor/github.com/containerd/containerd/api/services/namespaces/v1/namespace.proto",
     "vendor/github.com/containerd/containerd/api/services/snapshots/v1/snapshots.proto",
     "vendor/github.com/containerd/containerd/api/services/version/v1/version.proto",
+    "vendor/github.com/containerd/containerd/api/services/tasks/v1/tasks.proto",
     // Events
     "vendor/github.com/containerd/containerd/api/events/container.proto",
     "vendor/github.com/containerd/containerd/api/events/content.proto",
@@ -50,6 +51,7 @@ const FIXUP_MODULES: &[&str] = &[
     "containerd.services.images.v1",
     "containerd.services.introspection.v1",
     "containerd.services.snapshots.v1",
+    "containerd.services.tasks.v1",
 ];
 
 fn main() {
@@ -73,12 +75,13 @@ fn main() {
 // 47 |     pub diff: ::core::option::Option<super::super::super::types::Descriptor>,
 //    |                                                    ^^^^^ there are too many leading `super` keywords
 //
-// This func aims to fix these imports to crate level ones, like `crate::types::Mount`
+// This func fixes imports to crate level ones, like `crate::types::Mount`
 fn fixup_imports(path: &str) -> Result<(), io::Error> {
     let out_dir = env::var("OUT_DIR").unwrap();
     let path = format!("{}/{}.rs", out_dir, path);
 
     let contents = fs::read_to_string(&path)?
+        .replace("super::super::super::v1::types", "crate::types::v1") // for tasks service
         .replace("super::super::super::types", "crate::types")
         .replace("super::super::super::super::google", "crate::google");
     fs::write(path, contents)?;
